@@ -5,7 +5,10 @@ renameDictionary = {
     "Lokaler": "Lokale"
 }
 def fravær(self):
-    resp = self.session.get(f"https://www.lectio.dk/lectio/{self.skoleId}/subnav/fravaerelev.aspx?elevid={self.elevId}")
+    url = f"https://www.lectio.dk/lectio/{self.skoleId}/subnav/fravaerelev.aspx?elevid={self.elevId}"
+    resp = self.session.get(url)
+    if resp.url != url:
+        raise Exception("lectio-cookie udløbet")
     soup = BeautifulSoup(resp.text, "html.parser")
 
     fravær = {
@@ -23,6 +26,7 @@ def fravær(self):
             fravær["generalt"].append({
                 "hold": row[0].text,
                 "fravær_procent": row[1].text,
+                "fravær_moduler": row[2].text,
             })
 
     resp = self.session.get(f"https://www.lectio.dk/lectio/{self.skoleId}/subnav/fravaerelev_fravaersaarsager.aspx?elevid={self.elevId}")
@@ -112,4 +116,4 @@ def fravær(self):
                 "årsagsnote": tds[9].text.lstrip(),
             })
 
-    return fravær
\ No newline at end of file
+    return fravær
